@@ -2262,13 +2262,13 @@ class DuPanFileSystem:
         try:
             attr = self.attr(path, _check=False)
         except FileNotFoundError:
+            return Error.check(self.client.makedir(path))["path"]
+        else:
             if exist_ok:
                 if not attr["isdir"]:
                     raise NotADirectoryError(errno.ENOTDIR, path)
             else:
                 raise FileExistsError(errno.EEXIST, path)
-        else:
-            return Error.check(self.client.makedir(path))["path"]
         return path
 
     def mkdir(
@@ -2650,7 +2650,7 @@ class DuPanFileSystem:
             return self.upload(BytesIO(), path, _check=False)
         return path
 
-    # TODO: 确保转存后也保持目录结构
+    # TODO: 如果文件特别多，需要分多次进行转存，但要保持目录结构
     def transfer(
         self, 
         /, 
@@ -2664,14 +2664,15 @@ class DuPanFileSystem:
         :param url: 分享链接
         :param password: 密码（如果链接中包含密码，可以不传）
         :param fsidlist: 待转存的文件 id 列表
-        :param save_dir: 存储到这个文件夹，默认是 /，也就是网盘根目录（请提前建立这个文件夹）
+        :param save_dir: 存储到这个文件夹，默认是 /，也就是网盘根目录
 
         :return: 转存接口返回到 JSON 信息
         """
+        self.makedirs(save_dir, exist_ok=True)
         share_list = DuPanShareList(url, password)
         if not fsidlist:
             fsidlist = [f["fs_id"] for f in share_list.list_index()]
-        return self.client.transfer(
+        return Error.check(self.client.transfer(
             share_list.url, 
             params={
                 "shareid": share_list.share_id, 
@@ -2680,7 +2681,7 @@ class DuPanFileSystem:
                 "ondup": "overwrite", 
             }, 
             data = {"fsidlist": fsidlist, "path": save_dir}, 
-        )
+        ))
 
     def upload(
         self, 
